@@ -194,6 +194,7 @@ pub struct InsertOpt {
 }
 
 fn main() -> Result<(), Error> {
+
     let opt = Cli::parse();
 
     let verbose = if opt.quiet {
@@ -248,10 +249,18 @@ fn main() -> Result<(), Error> {
         }
         Command::Completions { shell, output } => {
             let mut output = File::create(output)?;
-            generate(shell, &mut Cli::into_app(), "odbc2parquet", &mut output);
+            generate(shell, &mut Cli::command(), "odbc2parquet", &mut output);
         }
     }
 
+    println!(
+        "Peace for the citizens of Ukraine who fight for their freedom and stand up to oppression. \
+        Peace for the Russian soldier, who does not know why he is shooting at his brothers and \
+        sisters, may he be reunited with his family soon.
+        
+        Peace to 🇺🇦, 🇷🇺 and the world. May sanity prevail.
+    ");
+
     Ok(())
 }
 
